# APP_NAME_PLACEHOLDER

My new awesome homebrew application for the Nintendo Switch, created with [BrewJS](https://github.com/BrewJS).

[![generated_by nxstart](https://img.shields.io/badge/generated_by-nxstart-blue.svg)](https://github.com/roedesh/nxstart)

## Features

...

## Getting Started

Download the [latest release of BrewJS](https://github.com/BrewJS/Switch/archive/master.zip) 
and copy the `switch` folder to your SD card. Now you can run BrewJS games!

### Running the app

Copy this folder to `sdmc:/switch/Brew.js/`. 
Now you can run this app on your Switch via BrewJS.

## Author

APP_AUTHOR_PLACEHOLDER
